@@ -17,7 +17,7 @@ use Net::Statsd::Tiny::Types -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 
 has host => (
@@ -89,7 +89,7 @@ BEGIN {
     my $class = __PACKAGE__;
 
     my %PROTOCOL = (
-        add_set   => [ 's',  Str, ],
+        set_add   => [ 's',  Str, ],
         counter   => [ 'c',  Int, 1 ],
         gauge     => [ 'g',  Gauge | PosInt ],
         histogram => [ 'h',  PosNum ],
@@ -143,6 +143,7 @@ BEGIN {
 
         *{"${class}::update"}    = set_subname "update"    => \&counter;
         *{"${class}::timing_ms"} = set_subname "timing_ms" => \&timing;
+        *{"${class}::add_set"}   = set_subname "timing_ms" => \&set_add;
 
     }
 
@@ -218,7 +219,7 @@ Net::Statsd::Tiny - A tiny StatsD client
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
 
 =head1 SYNOPSIS
 
@@ -234,7 +235,7 @@ version v0.1.0
 
     $stats->increment('this.counter');
 
-    $stats->add_set( $username ) if $username;
+    $stats->set_add( $username ) if $username;
 
     $stats->timing( $run_time * 1000 );
 
@@ -378,13 +379,18 @@ This logs a value so that statistics about the metric can be
 gathered. The C<$value> must be a positive number, although the
 specification recommends that integers be used.
 
-=head2 C<add_set>
+=head2 C<set_add>
 
-  $stats->add_set( $metric, $string );
+  $stats->set_add( $metric, $string );
 
 This adds the the C<$string> to a set, for logging the number of
 unique things, e.g. IP addresses or usernames.
 
+=head2 C<add_set>
+
+This is an alias for L</set_add>. It is deprecated and will be removed
+in a later version.
+
 =head2 C<flush>
 
 This sends the buffer to the L</host> and empties the buffer, if there
